var observation_8h =
[
    [ "isc::stats::InvalidStatType", "d6/d5c/classisc_1_1stats_1_1InvalidStatType.html", "d6/d5c/classisc_1_1stats_1_1InvalidStatType" ],
    [ "isc::stats::Observation", "d4/d18/classisc_1_1stats_1_1Observation.html", "d4/d18/classisc_1_1stats_1_1Observation" ],
    [ "DurationSample", "d3/dab/observation_8h.html#ga808e5da116191c0b81987c5de8ad6c3d", null ],
    [ "FloatSample", "d3/dab/observation_8h.html#ga886cd3fc41ff142aa614211d30238ba4", null ],
    [ "IntegerSample", "d3/dab/observation_8h.html#gad92d7dbdd7952c541bd33d0a5b274ad7", null ],
    [ "ObservationPtr", "d3/dab/observation_8h.html#a628dfd5ba6148fe428852217f183e483", null ],
    [ "StatsDuration", "d3/dab/observation_8h.html#a400c60cc77b35ee3b4f1f422b166aa97", null ],
    [ "StringSample", "d3/dab/observation_8h.html#gad345f9a74b597bbd2ca6512baa2d142d", null ]
];